==> afni_0.20110610~dfsg.1.orig.tar.gz: afni-0.20110610~dfsg.1/SUMA/SUMA_ParseName.c <==
   
/* Header FILES */
#include "SUMA_suma.h"
   
#if 1
void usageParseName_Main ()
  {/*Usage*/
printf (
   "\n"
   "Usage:  ParseName [OPTIONS] <FName> \n"
   "Parses filename FName into components useful for AFNI\n"
   "The program makes no attempt to check that the file exists.\n"
   "OPTIONS:\n"
   "   -cwd: Specify the working directory, from which relative\n"
   "         path is constructed. Default is the program's CWD"
   "   -out OUT: Output only one component of the parsed file name\n"
   "             By default the whole parsed filename structure is\n"
   "             displayed.\n"
   "             OUT is one of the following:\n"
   "        FullName: ABSOLUTE_PATH/FName\n"
   "        RelName : RELATIVE_PATH/FName\n"
   "        AbsPath : ABSOLUTE_PATH/\n"
   "        RelPath : RELATIVE_PATH/\n"
   "\n"
   "Tests:\n"
   "    ParseName -cwd /hello/Joe /hello/Joe/afni.c\n"
   "    ParseName -cwd /hello/Joe/ /hello/Jane/afni.c\n"
   "\n"
   "     Ziad S. Saad SSCC/NIMH/NIH saadz@mail.nih.gov \n"
   "\n");
   exit (0);
  }/*Usage*/
   
int main (int argc,char *argv[])
{/* Main */
   static char FuncName[]={"ParseName"}; 
	char *out=NULL,*FName=NULL, *cwd=NULL;
   int kar, brk;
   SUMA_PARSED_NAME *Test;
   
	SUMAg_CF = SUMA_Create_CommonFields ();
	if (SUMAg_CF == NULL) {
		SUMA_S_Err("Failed in SUMA_Create_CommonFields\n");
		exit(1);
	}

   
   if (argc < 2) {
      usageParseName_Main ();
      exit (0);
   }
      
   kar = 1;
   cwd = NULL;
   out = NULL;
   brk = NOPE;
	while (kar < argc) { /* loop accross command ine options */
		/*fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName);*/
		if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
          usageParseName_Main ();
          exit (0);
		}
		
		SUMA_SKIP_COMMON_OPTIONS(brk, kar);
      
      if (!brk && (strcmp(argv[kar], "-cwd") == 0))
      {
         if (kar+1 >= argc)
         {
            fprintf (SUMA_STDERR, "need a path after -cwd \n");
            exit (1);
         }
         
         cwd = argv[++kar];
         if (cwd[0] != '/') {
            SUMA_S_Errv("-cwd must specify an abosulte directory path\n"
                        "Have %s on command line.\n", cwd);
            exit(1);
         }
         brk = YUP;
      }

      if (!brk && (strcmp(argv[kar], "-out") == 0))
      {
         if (kar+1 >= argc)
         {
            fprintf (SUMA_STDERR, "need a string after -out \n");
            exit (1);
         }
         
         out = argv[++kar];
         brk = YUP;
      }

      
      if (!brk) {
			if (kar+1 == argc) {
            FName = argv[kar];
            ++kar;
         } else {
            SUMA_S_Errv("Option %s not understood.\n"
                        "FName must be the last option on command line .\n"
                        "Try -help for usage\n", 
                        argv[kar]);
			   exit (1);
		   }
      } else {	
			brk = NOPE;
			kar ++;
		}
   }
   
   if (!FName) {
      SUMA_S_Err("No FName, nothing to do");
      exit(1);
   }
   if (!cwd) cwd = SUMAg_CF->cwd;
	
   if (!(Test = SUMA_ParseFname (FName, cwd))) {
      SUMA_S_Errv("Failed to parse %s, cwd %s\n", FName, cwd);
      exit(1);
   }
   
   if (out) {
      if (strcmp(out,"RelName") == 0) {
         fprintf(SUMA_STDOUT, "%s%s\n", 
                     Test->RelPath,Test->FileName);
      } else if (strcmp(out,"FullName") == 0) {
         fprintf(SUMA_STDOUT, "%s\n", 
                     Test->FullName);
      } else if (strcmp(out,"AbsPath") == 0) {
         fprintf(SUMA_STDOUT, "%s\n", 
                     Test->AbsPath);
      } else if (strcmp(out,"RelPath") == 0) {
         fprintf(SUMA_STDOUT, "%s\n", 
                     Test->RelPath);
      } else {
         SUMA_S_Errv("Bad -out option of %s\n", out);
         exit(1);
      }
   } else {
      SUMA_ShowParsedFname(Test, NULL);
   }
   
   if (Test) SUMA_Free_Parsed_Name (Test);
   
   exit (0);
}/* Main */
#endif

==> afni_0.20121123~dfsg.1.orig.tar.gz: afni-0.20121123~dfsg.1/SUMA/SUMA_ParseName.c <==
   
/* Header FILES */
#include "SUMA_suma.h"

#if 1
void usageParseName_Main ()
  {/*Usage*/
printf (
   "\n"
   "Usage:  ParseName [OPTIONS] <FName> \n"
   "Parses filename FName into components useful for AFNI\n"
   "OPTIONS:\n"
   "   -cwd: Specify the working directory, from which relative\n"
   "         path is constructed. Default is the program's CWD\n"
   "   -pre PRE: Change the name so that you prepend PRE to the prefix\n"
   "   -app APP: Change the name so that you append APP to the prefix\n"
   "\n"
   "   -out OUT: Output only one component of the parsed file name\n"
   "             By default the whole parsed filename structure is\n"
   "             displayed.\n"
   "             OUT is one of the following:\n"
   "        FullName: ABSOLUTE_PATH/FName\n"
   "        RelName : RELATIVE_PATH/FName\n"
   "        AbsPath : ABSOLUTE_PATH/\n"
   "        RelPath : RELATIVE_PATH/\n"
   "        HeadName: RELATIVE_PATH/HEADNAME\n"
   "        Prefix  : PREFIX\n"
   "        uPrefix : USER_PATH/PREFIX\n"
   "        pPrefix : RELATIVE_PATH/PREFIX\n"
   "        PPrefix : ABSOLUTE_PATH/PREFIX\n"
   "        trim    : Trim the name to 20 characters.\n"
   "                  First the path goes, then extension, then view,\n"
   "                  then characters from the left. '~' indicates clipping.\n"
   "\n"
   "Tests:\n"
   "    ParseName -cwd /hello/Joe /hello/Joe/afni.c\n"
   "    ParseName -cwd /hello/Joe/ /hello/Jane/afni.c\n"
   "    ParseName -out Prefix something.nii\n"
   "    ParseName -pre Need_ -out Prefix something.nii\n"
   "    ParseName -pre Need_  something.nii'[65-88]'\n"
   "    ParseName -pre Need_  something+orig.HEAD'{2-10}[4-6]'\n"
   "    ParseName -pre Need_ -out HeadName  something+orig.HEAD'{2-10}[4-6]'\n"
   "\n"
   "     Ziad S. Saad SSCC/NIMH/NIH saadz@mail.nih.gov \n"
   "\n");
   exit (0);
  }/*Usage*/
   
int main (int argc,char *argv[])
{/* Main */
   static char FuncName[]={"ParseName"}; 
	char *out=NULL,*FName=NULL, *cwd=NULL, *what=NULL, *val=NULL;
   int kar, brk;
   SUMA_PARSED_NAME *Test;
   
	SUMAg_CF = SUMA_Create_CommonFields ();
	if (SUMAg_CF == NULL) {
		SUMA_S_Err("Failed in SUMA_Create_CommonFields\n");
		exit(1);
	}

   
   if (argc < 2) {
      usageParseName_Main ();
      exit (0);
   }
      
   kar = 1;
   cwd = NULL;
   out = NULL;
   what = NULL;
   val = NULL;
   brk = NOPE;
	while (kar < argc) { /* loop accross command ine options */
		/*fprintf(stdout, "%s verbose: Parsing command line...\n", FuncName);*/
		if (strcmp(argv[kar], "-h") == 0 || strcmp(argv[kar], "-help") == 0) {
          usageParseName_Main ();
          exit (0);
		}
		
		SUMA_SKIP_COMMON_OPTIONS(brk, kar);
      
      if (!brk && (strcmp(argv[kar], "-cwd") == 0))
      {
         if (kar+1 >= argc)
         {
            fprintf (SUMA_STDERR, "need a path after -cwd \n");
            exit (1);
         }
         
         cwd = argv[++kar];
         if (cwd[0] != '/') {
            SUMA_S_Errv("-cwd must specify an abosulte directory path\n"
                        "Have %s on command line.\n", cwd);
            exit(1);
         }
         brk = YUP;
      }

      if (!brk && (strcmp(argv[kar], "-out") == 0))
      {
         if (kar+1 >= argc)
         {
            fprintf (SUMA_STDERR, "need a string after -out \n");
            exit (1);
         }
         
         out = argv[++kar];
         brk = YUP;
      }

      if (!brk && (strcmp(argv[kar], "-pre") == 0))
      {
         if (kar+1 >= argc)
         {
            fprintf (SUMA_STDERR, "need a string after -pre \n");
            exit (1);
         }
         what = "prepend";
         val = argv[++kar];
         brk = YUP;
      }
      
      if (!brk && (strcmp(argv[kar], "-app") == 0))
      {
         if (kar+1 >= argc)
         {
            fprintf (SUMA_STDERR, "need a string after -app \n");
            exit (1);
         }
         what = "append";
         val = argv[++kar];
         brk = YUP;
      }

      
      if (!brk) {
			if (kar+1 == argc) {
            FName = argv[kar];
            ++kar;
         } else {
            SUMA_S_Errv("Option %s not understood.\n"
                        "FName must be the last option on command line .\n"
                        "Try -help for usage\n", 
                        argv[kar]);
			   suggest_best_prog_option(argv[0], argv[kar]);
            exit (1);
		   }
      } else {	
			brk = NOPE;
			kar ++;
		}
   }
   
   if (!FName) {
      SUMA_S_Err("No FName, nothing to do");
      exit(1);
   }
   if (!cwd) cwd = SUMAg_CF->cwd;
	
   
   if (what) {
      if (!(Test = SUMA_ParseModifyName(FName, what, val, cwd))) {
          SUMA_S_Errv("Failed to parse %s, cwd %s, what %s, val %s\n", 
               FName, cwd, what, val);
         exit(1);
      }
   } else {
      if (!(Test = SUMA_ParseFname (FName, cwd))) {
         SUMA_S_Errv("Failed to parse %s, cwd %s\n", FName, cwd);
         exit(1);
      }
   }
   
   if (out) {
      if (strcmp(out,"RelName") == 0) {
         fprintf(SUMA_STDOUT, "%s%s\n", 
                     Test->RelPath,Test->FileName);
      } else if (strcmp(out,"FullName") == 0) {
         fprintf(SUMA_STDOUT, "%s\n", 
                     Test->FullName);
      } else if (strcmp(out,"AbsPath") == 0) {
         fprintf(SUMA_STDOUT, "%s\n", 
                     Test->AbsPath);
      } else if (strcmp(out,"RelPath") == 0) {
         fprintf(SUMA_STDOUT, "%s\n", 
                     Test->RelPath);
      } else if (strcmp(out,"Prefix") == 0) {
         fprintf(SUMA_STDOUT, "%s\n", 
                     Test->Prefix);
      } else if (strcmp(out,"uPrefix") == 0) {
         fprintf(SUMA_STDOUT, "%s%s\n", 
                     Test->Path,Test->Prefix);
      } else if (strcmp(out,"PPrefix") == 0) {
         fprintf(SUMA_STDOUT, "%s%s\n", 
                     Test->AbsPath,Test->Prefix);
      } else if (strcmp(out,"pPrefix") == 0) {
         fprintf(SUMA_STDOUT, "%s%s\n", 
                     Test->RelPath,Test->Prefix);
      } else if (strcmp(out,"HeadName") == 0) {
         fprintf(SUMA_STDOUT, "%s\n", 
                     Test->HeadName);
      } else if (strcmp(out,"OnDisk") == 0) {
         fprintf(SUMA_STDOUT, "%d\n", 
                     Test->OnDisk);
      } else if (strncmp(out,"trim",4) == 0) {
         int mxlen=20;
         if (strlen(out) == 4) mxlen = 20;
         else mxlen = (int)strtod(out+4,NULL);
         fprintf(SUMA_STDOUT, "%s\n", 
                     TrimString(Test->HeadName,mxlen));
      } else {
         SUMA_S_Errv("Bad -out option of %s\n", out);
         exit(1);
      }
   } else {
      SUMA_ShowParsedFname(Test, NULL);
   }
   
   if (Test) SUMA_Free_Parsed_Name (Test);
   
   exit (0);
}/* Main */
#endif
